@@ -71,9 +71,9 @@ autoplot.clustcurves <- function(object = object, groups_by_colour = TRUE,
   k <- length(unique(x$cluster))
 
    if(k < 3){
-     colgr <- brewer.pal(n = 3, name = "Dark2")
+     colgr <- RColorBrewer::brewer.pal(n = 3, name = "Dark2")
    }else if(k<9){
-     colgr <- brewer.pal(n = k, name = "Dark2")
+     colgr <- RColorBrewer::brewer.pal(n = k, name = "Dark2")
      }else{
   colgr <- colorRampPalette(brewer.pal(n = 8, name = "Dark2"))(k)
      }
