@@ -1,3 +1,4 @@
+
 #' Clustering multiple survival curves
 #'
 #' @description Function for grouping survival  curves based on the k-means or
@@ -12,12 +13,22 @@
 #'  checking.
 #' @param kbin Size of the grid over which the survival functions
 #' are to be estimated.
-#' @param nboot Number of bootstrap repeats.
+#' @param method  Testing procedure used for obtain the number of groups. Default is \code{"LR"}
+#' Possible values are one of:
+#' - "LR": Regular Log-Rank test, sensitive to detect late differences.
+#' - "GB": Gehan-Breslow (generalized Wilcoxon), detect early differences.
+#' - "TW": Tarone-Ware, detect early differences.
+#' - "PP": Peto-Peto's modified survival estimate, more robust than
+#' Tharone-Ware or Gehan-Breslow, detect early differences
+#' - "mPP": modified Peto-Peto (by Andersen)
+#' - "FH": Fleming-Harrington (p = 1, q = 1)
+#' - "bootstrap": Villanueva, Sestelo & Meira-Machado bootstrap procedure.
+#' @param nboot Number of bootstrap repeats.Only for bootstrap method.
 #' @param algorithm A character string specifying which clustering algorithm is used,
 #'  i.e., k-means(\code{"kmeans"}) or k-medians (\code{"kmedians"}).
 #' @param alpha Significance level of the testing procedure. Defaults to 0.05.
-#' @param cluster A logical value. If  \code{TRUE} (default), the
-#'  testing procedure is  parallelized. Note that there are cases
+#' @param cluster A logical value. If  \code{FALSE} (default), the
+#'  bootstrap testing procedure is  parallelized. Note that there are cases
 #'  (e.g., a low number of bootstrap repetitions) that R will gain in
 #'  performance through serial computation. R takes time to distribute tasks
 #'  across the processors also it will need time for binding them all together
@@ -28,9 +39,8 @@
 #' in the parallelized procedure. If \code{NULL} (default), the number of cores
 #' to be used is equal to the number of cores of the machine - 1.
 #' @param seed Seed to be used in the procedure.
-#' @param multiple A logical value. If  \code{TRUE} (not default), the resulted
-#' pvalues are adjusted by using one of several methods for multiple comparisons.
-#' @param multiple.method Correction method. See Details.
+#' @param multiple.method Correction for multiple comparisons. See Details. Not used
+#' in the case of the bootstrap method.
 #'
 #'@return
 #'A list containing the following items:
@@ -49,7 +59,8 @@
 #' Hochberg (1988) ('hochberg'), Hommel (1988) ('hommel'),
 #' Benjamini & Hochberg (1995) ('BH' or its alias 'fdr'), and
 #' Benjamini & Yekutieli (2001) ('BY'), respectively.
-#' A pass-through option ('none') is also included.
+#'
+#' This correction is not applied in the bootstrap method.
 #'
 #'
 #'@author Nora M. Villanueva and Marta Sestelo.
@@ -87,20 +98,19 @@
 
 
 survclustcurves <- function(time, status = NULL, x,
-                           kvector = NULL, kbin = 50,
-                           nboot = 100, algorithm = 'kmeans', alpha = 0.05,
-                           cluster = FALSE, ncores = NULL, seed = NULL,
-                           multiple = FALSE, multiple.method = 'holm'){
+                            kvector = NULL, kbin = 50, method = "LR",
+                            nboot = 100, algorithm = 'kmeans', alpha = 0.05,
+                            cluster = FALSE, ncores = NULL, seed = NULL,
+                            multiple.method = 'bonferroni'){
 
 
   y <- time
   weights <- status
   z <- x
-  method <- "survival"
+
 
   # Defining error codes
   error.code.0 <- "Argument seed must be an object of type numeric."
- # error.code.1 <- "Argument method must be a string with 'survival' or 'regression'."
   error.code.2 <- "Argument algorithm must be a string with 'kmeans' or 'kmedians'."
   error.code.3 <- "Argument multiple must be an object of type logical."
   error.code.4 <- "Argument multiple.method must be an object of type string."
@@ -108,21 +118,9 @@ survclustcurves <- function(time, status = NULL, x,
   error.code.6 <- "Argument kvector must be an object of type numeric."
   error.code.7 <- "Argument status is missing and it is required."
   error.code.8 <- "Argument status must be a vector of binary numbers."
- # error.code.9 <- "Argument x is missing and it is required when method is 'regression'."
   error.code.10 <- "Argument y is missing and it is required."
- # error.code.11 <- "Argument y is missing and it is required when method is 'regression'."
 
 
-  # # Checking method  as strings and type
-  # if(missing(method)){
-  #   stop(error.code.1)
-  # }else if (!is.character(method) ) {
-  #   stop(error.code.1)
-  # }else if (nchar(method)!= 8 & nchar(method)!= 10) {
-  #   stop(error.code.1)
-  # }else if(method != 'survival' & method != 'regression') {
-  #   stop(error.code.1)
-  # }
 
   # Checking algorithm  as string and type
   if (!is.character(algorithm) ) {
@@ -133,17 +131,7 @@ survclustcurves <- function(time, status = NULL, x,
     stop(error.code.2)
   }
 
-  # Checking multiple  as logical
-  if (!is.logical(multiple) ) {
-    stop(error.code.3)
-  }
 
-  # Checking multiple.method as string
-  if (!is.character(multiple.method)  )  {
-    stop(error.code.4)
-  }else if(nchar(multiple.method) == 0){
-      stop(error.code.5)
-  }
 
 
   # Checking seed as numeric
@@ -196,98 +184,79 @@ survclustcurves <- function(time, status = NULL, x,
     }
 
 
-    if(method == 'survival'){
-      if(missing(weights)) {
-        stop(error.code.7)
-      }else if(length(unique(weights)) > 2){
-          stop(error.code.8)
-      }else if(sum(unique(weights))>1 | sum(unique(weights))<0){
-          stop(error.code.8)
-      }
-
-      if(missing(y)) {
-        stop(error.code.10)
-      }
-
-    aux[[ii]] <- testing_k(time = time, status = status, fac = fac, k = k,
-                     kbin = kbin, nboot = nboot, algorithm = algorithm,
-                     seed = seed, cluster = cluster)
-    data <- NULL
 
+    if(missing(weights)) {
+      stop(error.code.7)
+    }else if(length(unique(weights)) > 2){
+      stop(error.code.8)
+    }else if(sum(unique(weights))>1 | sum(unique(weights))<0){
+      stop(error.code.8)
     }
 
+    if(missing(y)) {
+      stop(error.code.10)
+    }
+
+    if(method == "bootstrap"){
+      aux[[ii]] <- testing_k(time = time, status = status, fac = fac, k = k,
+                             kbin = kbin, nboot = nboot, algorithm = algorithm,
+                             seed = seed, cluster = cluster)
+    }else{
+      aux[[ii]] <- testing_k_LR(time = time, status = status, fac = fac, k = k,
+                                kbin = kbin, stat = method, nboot = nboot, algorithm = algorithm,
+                                seed = seed, cluster = cluster, correction = multiple.method)
+    }
+    data <- NULL
 
 
 
     pval[ii] <- aux[[ii]]$pvalue
     tval[ii] <- aux[[ii]]$t
     h0tested[ii] <- k
-
-
-    if(isTRUE(multiple)){
-      pval <- p.adjust(pval, method = multiple.method)
-      ind <- pval >= alpha
-      if(sum(ind) > 0){
-        ind_list <- which(ind)[1]
-        k <- kvector[ind_list]
-        aux <- aux[[ind_list]]
-        accept <- 1
-        break
-        }
-      }
-
+    # multiple <- FALSE # for bootstrap procedure the correction is not applied
+    # if(isTRUE(multiple)){
+    #   pval <- p.adjust(pval, method = multiple.method)
+    #   ind <- pval >= alpha
+    #   if(sum(ind) > 0){
+    #     ind_list <- which(ind)[1]
+    #     k <- kvector[ind_list]
+    #     aux <- aux[[ind_list]]
+    #     accept <- 1
+    #     break
+    #     }
+    #   }
     if(aux[[ii]]$pvalue >= alpha){
       aux <- aux[[ii]]
       accept <- 1
       break
-      }
+    }
     ii <- ii + 1
   }
 
 
   if (accept == 1) {
 
-  if(k == 1){
-    cat("\n")
-    cat(paste("Finally, there is one cluster.", "\n"), sep = "")
-  }else{
-    cat("\n")
-    cat(paste("Finally, there are",k, "clusters.", "\n"), sep = "")
-  }
+    if(k == 1){
+      cat("\n")
+      cat(paste("Finally, there is one cluster.", "\n"), sep = "")
+    }else{
+      cat("\n")
+      cat(paste("Finally, there are",k, "clusters.", "\n"), sep = "")
+    }
 
+    # muhat under h0 and under h1
 
-  # muhat under h0 and under h1
-
-  if(method == 'survival'){
-  h0 <- survfit(Surv(time, status) ~ aux$cluster[fac])
-  h1 <- survfit(Surv(time, status) ~ fac)
-  }
-  #   else{
-  #   data <- data.frame(x = x, y = y, f = z)
-  # #h0 <- aux$centers
-  #   data0 <- data
-  #   data0$f <- aux$levels[aux$cluster[data$f]]
-  #   h0 <- by(data0, data0$f, muhatrfast2, h = h, kbin = kbin)
-  # #h1 <- aux$muhat
-  # h1 <- by(data, data$f, muhatrfast2, h = h, kbin = kbin)
-  # }
+    ii <- aux$cluster[as.factor(fac)]
+    h0 <- survfit(Surv(time, status) ~ ii)
+    h1 <- survfit(Surv(time, status) ~ fac)
 
   }else{
     k <- paste( ">", k, sep ="")
     aux$levels <- NA
     aux$cluster <- NA
     h0 <- NA
-    if(method == 'survival'){
     h1 <- survfit(Surv(time, status) ~ fac)
-    }
-    # else{
-    # #h1 <- aux$muhat
-    #   data <- data.frame(x = x, y = y, f = z)
-    #   h1 <- by(data, data$f, muhatrfast2, h = h, kbin = kbin)
-    #
-    #
-    #
-    # }
+
     cat("\n")
     cat(paste("The number 'k' of clusters has not been found, try another kvector.", "\n"), sep = "")
 
@@ -295,12 +264,9 @@ survclustcurves <- function(time, status = NULL, x,
 
   res <- list(num_groups = k, table = data.frame(H0 = h0tested, Tvalue = tval, pvalue = pval),
               levels = aux$levels, cluster = as.numeric(aux$cluster),
-              centers = h0, curves = h1, method = method, data = data, algorithm = algorithm,
+              centers = h0, curves = h1, method = "survival", data = data, algorithm = algorithm,
               call = match.call())
   class(res) <- "clustcurves"
   return(res)
 
 } #end clustcurv
-
-
-
