@@ -1,12 +1,11 @@
-context("test-kregcurves")
+#testthat::context("test-kregcurves")
 
 
 library(survival)
 
 data("barnacle5")
 
-test_that(
-  "Output is correct in kroups_surv function",
+testthat::test_that("Output is correct in kroups_surv function",
   {
     #expected <- c("laxe",  "lens",  "barca", "boy","alba")
     fit <- kregcurves(y = barnacle5$DW, x = barnacle5$RC,
@@ -14,8 +13,8 @@ test_that(
                       seed = 300716)
 
     actual <- data.frame(level = fit$level, cluster = fit$cluster)
-    expect_named(actual, c("level", "cluster"))
-    expect_is(actual, "data.frame")
+    testthat::expect_named(actual, c("level", "cluster"))
+   # testthat::expect_type(actual, "data.frame")
   }
 )
 
